@@ -5,15 +5,18 @@
 #include "util/scope_guard.hpp"
 
 waybar::modules::Custom::Custom(const std::string& name, const std::string& id,
-                                const Json::Value& config)
+                                const Json::Value& config, const std::string& output_name)
     : ALabel(config, "custom-" + name, id, "{}"),
       name_(name),
+      output_name_(output_name),
       id_(id),
+      tooltip_format_enabled_{config_["tooltip-format"].isString()},
       percentage_(0),
       fp_(nullptr),
       pid_(-1) {
   dp.emit();
-  if (!config_["signal"].empty() && config_["interval"].empty()) {
+  if (!config_["signal"].empty() && config_["interval"].empty() &&
+      config_["restart-interval"].empty()) {
     waitingWorker();
   } else if (interval_.count() > 0) {
     delayWorker();
@@ -42,7 +45,7 @@ void waybar::modules::Custom::delayWorker() {
     }
     if (can_update) {
       if (config_["exec"].isString()) {
-        output_ = util::command::exec(config_["exec"].asString());
+        output_ = util::command::exec(config_["exec"].asString(), output_name_);
       }
       dp.emit();
     }
@@ -53,7 +56,7 @@ void waybar::modules::Custom::delayWorker() {
 void waybar::modules::Custom::continuousWorker() {
   auto cmd = config_["exec"].asString();
   pid_ = -1;
-  fp_ = util::command::open(cmd, pid_);
+  fp_ = util::command::open(cmd, pid_, output_name_);
   if (!fp_) {
     throw std::runtime_error("Unable to open " + cmd);
   }
@@ -79,7 +82,7 @@ void waybar::modules::Custom::continuousWorker() {
       if (config_["restart-interval"].isUInt()) {
         pid_ = -1;
         thread_.sleep_for(std::chrono::seconds(config_["restart-interval"].asUInt()));
-        fp_ = util::command::open(cmd, pid_);
+        fp_ = util::command::open(cmd, pid_, output_name_);
         if (!fp_) {
           throw std::runtime_error("Unable to open " + cmd);
         }
@@ -112,7 +115,7 @@ void waybar::modules::Custom::waitingWorker() {
     }
     if (can_update) {
       if (config_["exec"].isString()) {
-        output_ = util::command::exec(config_["exec"].asString());
+        output_ = util::command::exec(config_["exec"].asString(), output_name_);
       }
       dp.emit();
     }
@@ -159,12 +162,18 @@ auto waybar::modules::Custom::update() -> void {
     auto str = fmt::format(fmt::runtime(format_), text_, fmt::arg("alt", alt_),
                            fmt::arg("icon", getIcon(percentage_, alt_)),
                            fmt::arg("percentage", percentage_));
-    if (str.empty()) {
+    if ((config_["hide-empty-text"].asBool() && text_.empty()) || str.empty()) {
       event_box_.hide();
     } else {
       label_.set_markup(str);
       if (tooltipEnabled()) {
-        if (text_ == tooltip_) {
+        if (tooltip_format_enabled_) {
+          auto tooltip = config_["tooltip-format"].asString();
+          tooltip = fmt::format(fmt::runtime(tooltip), text_, fmt::arg("alt", alt_),
+                                fmt::arg("icon", getIcon(percentage_, alt_)),
+                                fmt::arg("percentage", percentage_));
+          label_.set_tooltip_markup(tooltip);
+        } else if (text_ == tooltip_) {
           if (label_.get_tooltip_markup() != str) {
             label_.set_tooltip_markup(str);
           }
@@ -174,16 +183,18 @@ auto waybar::modules::Custom::update() -> void {
           }
         }
       }
-      auto classes = label_.get_style_context()->list_classes();
+      auto style = label_.get_style_context();
+      auto classes = style->list_classes();
       for (auto const& c : classes) {
         if (c == id_) continue;
-        label_.get_style_context()->remove_class(c);
+        style->remove_class(c);
       }
       for (auto const& c : class_) {
-        label_.get_style_context()->add_class(c);
+        style->add_class(c);
       }
-      label_.get_style_context()->add_class("flat");
-      label_.get_style_context()->add_class("text-button");
+      style->add_class("flat");
+      style->add_class("text-button");
+      style->add_class(MODULE_CLASS);
       event_box_.show();
     }
   }
@@ -204,13 +215,19 @@ void waybar::modules::Custom::parseOutputRaw() {
     if (i == 0) {
       if (config_["escape"].isBool() && config_["escape"].asBool()) {
         text_ = Glib::Markup::escape_text(validated_line);
+        tooltip_ = Glib::Markup::escape_text(validated_line);
       } else {
         text_ = validated_line;
+        tooltip_ = validated_line;
       }
       tooltip_ = validated_line;
       class_.clear();
     } else if (i == 1) {
-      tooltip_ = validated_line;
+      if (config_["escape"].isBool() && config_["escape"].asBool()) {
+        tooltip_ = Glib::Markup::escape_text(validated_line);
+      } else {
+        tooltip_ = validated_line;
+      }
     } else if (i == 2) {
       class_.push_back(validated_line);
     } else {
@@ -236,7 +253,11 @@ void waybar::modules::Custom::parseOutputJson() {
     } else {
       alt_ = parsed["alt"].asString();
     }
-    tooltip_ = parsed["tooltip"].asString();
+    if (config_["escape"].isBool() && config_["escape"].asBool()) {
+      tooltip_ = Glib::Markup::escape_text(parsed["tooltip"].asString());
+    } else {
+      tooltip_ = parsed["tooltip"].asString();
+    }
     if (parsed["class"].isString()) {
       class_.push_back(parsed["class"].asString());
     } else if (parsed["class"].isArray()) {
