@@ -590,8 +590,8 @@ auto Workspaces::populateIconsMap(const Json::Value &formatIcons) -> void {
   m_iconsMap.emplace("", "");
 }
 
-auto Workspaces::populateBoolConfig(const Json::Value &config, const std::string &key, bool &member)
-    -> void {
+auto Workspaces::populateBoolConfig(const Json::Value &config, const std::string &key,
+                                    bool &member) -> void {
   const auto &configValue = config[key];
   if (configValue.isBool()) {
     member = configValue.asBool();
